# !/usr/bin/env python
# -*- coding: utf-8 -*-

from taodata.util import auth
from taodata.util import client


def get_api(token='', timeout=30):
    """
    初始化API,第一次可以通过td.set_token('your token')来记录自己的token凭证，临时token可以通过本参数传入
    """
    if token == '' or token is None:
        token = auth.get_token()
    if token is not None and token != '':
        api = client.DataApi(token=token, timeout=timeout)
        return api
    else:
        raise Exception('api init error.')






# !/usr/bin/env python
# -*- coding: utf-8 -*-

import pandas as pd
from functools import partial
from taodata.util.dsl import BodyHelper
import json
import requests


class DataApi:

    __token = ''
    __http_url = 'http://210.22.185.58:7788/route'
    #__http_url = 'http://localhost:5000/route'

    def __init__(self, token, timeout=30):
        """
        Parameters
        ----------
        token: str
            API接口TOKEN，用于用户认证
        """
        self.__token = token
        self.__timeout = timeout

    # 得到专题列表
    # 参数
    def get_topics(self, **kwargs):
        req_params = {
            'action': 'get_topics',
            'token': self.__token,
            'params': kwargs,
        }
        res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
        if res:
            result = json.loads(res.text)
            if result['code'] != 0:
                raise Exception(result['msg'])
            data = result['data']
            return data
        else:
            return None

    # 获取专题下采集任务列表
    # 参数
    # topic_id
    def get_tasks(self, **kwargs):
        req_params = {
            'action': 'get_tasks',
            'token': self.__token,
            'params': kwargs,
        }
        res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
        if res:
            result = json.loads(res.text)
            if result['code'] != 0:
                raise Exception(result['msg'])
            data = result['data']
            return data
        else:
            return None

    # 获取专题数据字段
    # 参数
    # topic_id
    def get_topic_fields(self, **kwargs):
        req_params = {
            'action': 'get_topic_fields',
            'token': self.__token,
            'params': kwargs,
        }
        res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
        if res:
            result = json.loads(res.text)
            if result['code'] != 0:
                raise Exception(result['msg'])
            data = result['data']
            return data
        else:
            return None

    # 获取专题数据
    # 参数
    # topic_id  专题标识 不能为空
    # fields 专题字段ID列表，可以为空
    # scroll 使用游标 True,False 可以为空
    # scroll_id 游标获取数据标记
    # size 每次返回数据数，默认1000, 不能超过10000
    def get_topic_data(self, **kwargs):
        req_params = {
            'action': 'get_topic_data',
            'token': self.__token,
            'params': kwargs,
        }
        res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
        if res:
            result = json.loads(res.text)
            if result['code'] != 0:
                raise Exception(result['msg'])
            data = result['data']
            return data
        else:
            return None

    # 获取采集任务数据
    # 参数
    # task_id  采集任务标识 不能为空
    # fields 专题字段ID列表，可以为空
    # scroll 使用游标 True,False 可以为空
    # scroll_id 游标获取数据标记
    # size 每次返回数据数，默认1000, 不能超过10000
    def get_task_data(self, **kwargs):
        req_params = {
            'action': 'get_task_data',
            'token': self.__token,
            'params': kwargs,
        }
        res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
        if res:
            result = json.loads(res.text)
            if result['code'] != 0:
                raise Exception(result['msg'])
            data = result['data']
            return data
        else:
            return None




from taodata.util import client
from taodata.util import auth
import pandas as pd
if __name__ == '__main__':
    token = auth.get_token()
    api = client.DataApi(token=token)
    topics = api.get_topics()
    print(topics)

    ret = api.get_task_data(token='971969723014864896', task_id='185')
    df = pd.DataFrame(columns=ret['fields'],data=ret['records'])
    print(df)






class BodyHelper:

    must_clause = 'must'
    must_not_clause = 'must_not'
    should_clause = 'should_clause'

    def __init__(self):
        self.__bool_query = {
            'bool': {
                'must': [],
                'must_not': [],
                'should': []
            }
        }
        self.__from = 0
        self.__size = 10
        self.__sort = []

    # match phrase query
    def match_phrase(self, field, value, clause='must'):
        query = {
          "match_phrase": {
            field: value
          }
        }
        self.__append_query(clause, query)
        return self

    # match all query
    def match_all(self, clause='must'):
        query = {
          "match_all": {
          }
        }
        self.__append_query(clause, query)
        return self

    # term query
    def term(self, field, value, clause='must'):
        query = {
          'term': {
            field: {
              'value': value
            }
          }
        }
        self.__append_query(clause, query)
        return self

    # terms query
    def terms(self, field, values, clause='must'):
        query = {
          "terms": {
            field: values
          }
        }
        self.__append_query(clause, query)
        return self

    def set_minimum_should_match(self, minimum_should_match):
        self.__bool_query['bool']['minimum_should_match'] = minimum_should_match
        return self

    #
    def exists(self, field, clause='must'):
        query = {
            "exists": {
              "field": field
            }
        }
        self.__append_query(clause, query)

    def set_size(self, __size):
        self.__size = __size
        return self

    def set_from(self, __from):
        self.__from = __from
        return self

    def sort(self, field, order='asc'):
        self.__sort.append(
            {
                field: {
                    'order': order
                }
            }
        )
        return self

    # range query
    # format yyyy-MM-dd HH:mm:ss
    def range(self, field, gte=None, lte=None, gt=None, lt=None, format=None, clause='must'):
        if gte is None and lte is None and gt is None and lt is None:
            return

        query = {
          'range': {
            field: {
            }
          }
        }

        if gte:
            query['range'][field]['gte'] = gte

        if lte:
            query['range'][field]['lte'] = lte

        if gt:
            query['range'][field]['gt'] = gt

        if lt:
            query['range'][field]['lt'] = lt

        if format:
            query['range'][field]['format'] = format

        self.__append_query(clause, query)
        return self

    def __append_query(self, clause, query):
        if clause == 'must':
            self.__bool_query['bool']['must'].append(query)
        elif clause == 'should':
            self.__bool_query['bool']['should'].append(query)
        elif clause == 'must_not':
            self.__bool_query['bool']['must_not'].append(query)

    def to_json(self):
        # 构建 bool_query
        body = {
            'query': self.__bool_query,
            'from': self.__from,
            'size': self.__size,
            'sort': self.__sort
        }

        return body


if __name__ == '__main__':
    helper = BodyHelper()
    helper.match_phrase('blog.raw_text','战争','should').term('blog.id','12345').set_size(20).set_from(100).sort('blog.id')
    json1 = helper.to_json()
    print(json1)

    helper1 = BodyHelper()
    helper1.range(field='blog.status_count', lte=100).match_all()
    json2 = helper1.to_json()
    print(json2)




from setuptools import setup, find_packages
import codecs
import os


def read(fname):
    return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()


long_desc = """
todo
"""


def read_install_requires():
    reqs = [
        'requests',
        'pandas'
    ]
    return reqs


setup(
    name='taodata',
    version='0.1.13',
    description='todo',
    long_description=long_desc,
    author='Daniel Qian',
    author_email='909263817@qq.com',
    license='MIT',
    url='https://taodata.pro',
    install_requires=read_install_requires(),
    keywords='todo',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(),
    include_package_data=True,
    package_data={'': ['*.csv', '*.txt']},
)


from taodata.util import auth

if __name__ == '__main__':
    token = '971969723014864896'
    auth.set_token(token)
    local_token = auth.get_token()
    if token == local_token:
        print('it is passed!')
    else:
        print('it is failed!')
